v1alpha1

package
v0.2.8 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 17, 2026 License: MIT Imports: 9 Imported by: 0

Documentation

Overview

Package v1alpha1 is a generated GoMock package.

Package v1alpha1 is a generated GoMock package.

Package v1alpha1 is a generated GoMock package.

Package v1alpha1 is a generated GoMock package.

Package v1alpha1 is a generated GoMock package.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type MockDiskService

type MockDiskService struct {
	// contains filtered or unexported fields
}

MockDiskService is a mock of DiskService interface.

func NewMockDiskService

func NewMockDiskService(ctrl *gomock.Controller) *MockDiskService

NewMockDiskService creates a new mock instance.

func (*MockDiskService) Create

Create mocks base method.

func (*MockDiskService) Delete

Delete mocks base method.

func (*MockDiskService) EXPECT

EXPECT returns an object that allows the caller to indicate expected use.

func (*MockDiskService) Filter

Filter mocks base method.

func (*MockDiskService) Get

Get mocks base method.

func (*MockDiskService) GetByName

func (m *MockDiskService) GetByName(arg0 context.Context, arg1 *v1.GetByNameRequest, arg2 ...grpc.CallOption) (*v1alpha10.Disk, error)

GetByName mocks base method.

func (*MockDiskService) GetOperation

GetOperation mocks base method.

func (*MockDiskService) List

List mocks base method.

func (*MockDiskService) ListOperations

ListOperations mocks base method.

func (*MockDiskService) ListOperationsByParent

ListOperationsByParent mocks base method.

func (*MockDiskService) Update

Update mocks base method.

type MockDiskServiceCreateCall

type MockDiskServiceCreateCall struct {
	*gomock.Call
}

MockDiskServiceCreateCall wrap *gomock.Call

func (*MockDiskServiceCreateCall) Do

Do rewrite *gomock.Call.Do

func (*MockDiskServiceCreateCall) DoAndReturn

DoAndReturn rewrite *gomock.Call.DoAndReturn

func (*MockDiskServiceCreateCall) Return

Return rewrite *gomock.Call.Return

type MockDiskServiceDeleteCall

type MockDiskServiceDeleteCall struct {
	*gomock.Call
}

MockDiskServiceDeleteCall wrap *gomock.Call

func (*MockDiskServiceDeleteCall) Do

Do rewrite *gomock.Call.Do

func (*MockDiskServiceDeleteCall) DoAndReturn

DoAndReturn rewrite *gomock.Call.DoAndReturn

func (*MockDiskServiceDeleteCall) Return

Return rewrite *gomock.Call.Return

type MockDiskServiceFilterCall

type MockDiskServiceFilterCall struct {
	*gomock.Call
}

MockDiskServiceFilterCall wrap *gomock.Call

func (*MockDiskServiceFilterCall) Do

Do rewrite *gomock.Call.Do

func (*MockDiskServiceFilterCall) DoAndReturn

DoAndReturn rewrite *gomock.Call.DoAndReturn

func (*MockDiskServiceFilterCall) Return

Return rewrite *gomock.Call.Return

type MockDiskServiceGetByNameCall

type MockDiskServiceGetByNameCall struct {
	*gomock.Call
}

MockDiskServiceGetByNameCall wrap *gomock.Call

func (*MockDiskServiceGetByNameCall) Do

Do rewrite *gomock.Call.Do

func (*MockDiskServiceGetByNameCall) DoAndReturn

DoAndReturn rewrite *gomock.Call.DoAndReturn

func (*MockDiskServiceGetByNameCall) Return

Return rewrite *gomock.Call.Return

type MockDiskServiceGetCall

type MockDiskServiceGetCall struct {
	*gomock.Call
}

MockDiskServiceGetCall wrap *gomock.Call

func (*MockDiskServiceGetCall) Do

Do rewrite *gomock.Call.Do

func (*MockDiskServiceGetCall) DoAndReturn

DoAndReturn rewrite *gomock.Call.DoAndReturn

func (*MockDiskServiceGetCall) Return

Return rewrite *gomock.Call.Return

type MockDiskServiceGetOperationCall

type MockDiskServiceGetOperationCall struct {
	*gomock.Call
}

MockDiskServiceGetOperationCall wrap *gomock.Call

func (*MockDiskServiceGetOperationCall) Do

Do rewrite *gomock.Call.Do

func (*MockDiskServiceGetOperationCall) DoAndReturn

DoAndReturn rewrite *gomock.Call.DoAndReturn

func (*MockDiskServiceGetOperationCall) Return

Return rewrite *gomock.Call.Return

type MockDiskServiceListCall

type MockDiskServiceListCall struct {
	*gomock.Call
}

MockDiskServiceListCall wrap *gomock.Call

func (*MockDiskServiceListCall) Do

Do rewrite *gomock.Call.Do

func (*MockDiskServiceListCall) DoAndReturn

DoAndReturn rewrite *gomock.Call.DoAndReturn

func (*MockDiskServiceListCall) Return

Return rewrite *gomock.Call.Return

type MockDiskServiceListOperationsByParentCall

type MockDiskServiceListOperationsByParentCall struct {
	*gomock.Call
}

MockDiskServiceListOperationsByParentCall wrap *gomock.Call

func (*MockDiskServiceListOperationsByParentCall) Do

Do rewrite *gomock.Call.Do

func (*MockDiskServiceListOperationsByParentCall) DoAndReturn

DoAndReturn rewrite *gomock.Call.DoAndReturn

func (*MockDiskServiceListOperationsByParentCall) Return

Return rewrite *gomock.Call.Return

type MockDiskServiceListOperationsCall

type MockDiskServiceListOperationsCall struct {
	*gomock.Call
}

MockDiskServiceListOperationsCall wrap *gomock.Call

func (*MockDiskServiceListOperationsCall) Do

Do rewrite *gomock.Call.Do

func (*MockDiskServiceListOperationsCall) DoAndReturn

DoAndReturn rewrite *gomock.Call.DoAndReturn

func (*MockDiskServiceListOperationsCall) Return

Return rewrite *gomock.Call.Return

type MockDiskServiceMockRecorder

type MockDiskServiceMockRecorder struct {
	// contains filtered or unexported fields
}

MockDiskServiceMockRecorder is the mock recorder for MockDiskService.

func (*MockDiskServiceMockRecorder) Create

func (mr *MockDiskServiceMockRecorder) Create(arg0, arg1 any, arg2 ...any) *MockDiskServiceCreateCall

Create indicates an expected call of Create.

func (*MockDiskServiceMockRecorder) Delete

func (mr *MockDiskServiceMockRecorder) Delete(arg0, arg1 any, arg2 ...any) *MockDiskServiceDeleteCall

Delete indicates an expected call of Delete.

func (*MockDiskServiceMockRecorder) Filter

func (mr *MockDiskServiceMockRecorder) Filter(arg0, arg1 any, arg2 ...any) *MockDiskServiceFilterCall

Filter indicates an expected call of Filter.

func (*MockDiskServiceMockRecorder) Get

func (mr *MockDiskServiceMockRecorder) Get(arg0, arg1 any, arg2 ...any) *MockDiskServiceGetCall

Get indicates an expected call of Get.

func (*MockDiskServiceMockRecorder) GetByName

func (mr *MockDiskServiceMockRecorder) GetByName(arg0, arg1 any, arg2 ...any) *MockDiskServiceGetByNameCall

GetByName indicates an expected call of GetByName.

func (*MockDiskServiceMockRecorder) GetOperation

func (mr *MockDiskServiceMockRecorder) GetOperation(arg0, arg1 any, arg2 ...any) *MockDiskServiceGetOperationCall

GetOperation indicates an expected call of GetOperation.

func (*MockDiskServiceMockRecorder) List

func (mr *MockDiskServiceMockRecorder) List(arg0, arg1 any, arg2 ...any) *MockDiskServiceListCall

List indicates an expected call of List.

func (*MockDiskServiceMockRecorder) ListOperations

func (mr *MockDiskServiceMockRecorder) ListOperations(arg0, arg1 any, arg2 ...any) *MockDiskServiceListOperationsCall

ListOperations indicates an expected call of ListOperations.

func (*MockDiskServiceMockRecorder) ListOperationsByParent

func (mr *MockDiskServiceMockRecorder) ListOperationsByParent(arg0, arg1 any, arg2 ...any) *MockDiskServiceListOperationsByParentCall

ListOperationsByParent indicates an expected call of ListOperationsByParent.

func (*MockDiskServiceMockRecorder) Update

func (mr *MockDiskServiceMockRecorder) Update(arg0, arg1 any, arg2 ...any) *MockDiskServiceUpdateCall

Update indicates an expected call of Update.

type MockDiskServiceUpdateCall

type MockDiskServiceUpdateCall struct {
	*gomock.Call
}

MockDiskServiceUpdateCall wrap *gomock.Call

func (*MockDiskServiceUpdateCall) Do

Do rewrite *gomock.Call.Do

func (*MockDiskServiceUpdateCall) DoAndReturn

DoAndReturn rewrite *gomock.Call.DoAndReturn

func (*MockDiskServiceUpdateCall) Return

Return rewrite *gomock.Call.Return

type MockFilesystemService

type MockFilesystemService struct {
	// contains filtered or unexported fields
}

MockFilesystemService is a mock of FilesystemService interface.

func NewMockFilesystemService

func NewMockFilesystemService(ctrl *gomock.Controller) *MockFilesystemService

NewMockFilesystemService creates a new mock instance.

func (*MockFilesystemService) Create

Create mocks base method.

func (*MockFilesystemService) Delete

Delete mocks base method.

func (*MockFilesystemService) EXPECT

EXPECT returns an object that allows the caller to indicate expected use.

func (*MockFilesystemService) Filter

Filter mocks base method.

func (*MockFilesystemService) Get

Get mocks base method.

func (*MockFilesystemService) GetByName

GetByName mocks base method.

func (*MockFilesystemService) GetOperation

GetOperation mocks base method.

func (*MockFilesystemService) List

List mocks base method.

func (*MockFilesystemService) ListOperations

ListOperations mocks base method.

func (*MockFilesystemService) ListOperationsByParent

ListOperationsByParent mocks base method.

func (*MockFilesystemService) Update

Update mocks base method.

type MockFilesystemServiceCreateCall

type MockFilesystemServiceCreateCall struct {
	*gomock.Call
}

MockFilesystemServiceCreateCall wrap *gomock.Call

func (*MockFilesystemServiceCreateCall) Do

Do rewrite *gomock.Call.Do

func (*MockFilesystemServiceCreateCall) DoAndReturn

DoAndReturn rewrite *gomock.Call.DoAndReturn

func (*MockFilesystemServiceCreateCall) Return

Return rewrite *gomock.Call.Return

type MockFilesystemServiceDeleteCall

type MockFilesystemServiceDeleteCall struct {
	*gomock.Call
}

MockFilesystemServiceDeleteCall wrap *gomock.Call

func (*MockFilesystemServiceDeleteCall) Do

Do rewrite *gomock.Call.Do

func (*MockFilesystemServiceDeleteCall) DoAndReturn

DoAndReturn rewrite *gomock.Call.DoAndReturn

func (*MockFilesystemServiceDeleteCall) Return

Return rewrite *gomock.Call.Return

type MockFilesystemServiceFilterCall

type MockFilesystemServiceFilterCall struct {
	*gomock.Call
}

MockFilesystemServiceFilterCall wrap *gomock.Call

func (*MockFilesystemServiceFilterCall) Do

Do rewrite *gomock.Call.Do

func (*MockFilesystemServiceFilterCall) DoAndReturn

DoAndReturn rewrite *gomock.Call.DoAndReturn

func (*MockFilesystemServiceFilterCall) Return

Return rewrite *gomock.Call.Return

type MockFilesystemServiceGetByNameCall

type MockFilesystemServiceGetByNameCall struct {
	*gomock.Call
}

MockFilesystemServiceGetByNameCall wrap *gomock.Call

func (*MockFilesystemServiceGetByNameCall) Do

Do rewrite *gomock.Call.Do

func (*MockFilesystemServiceGetByNameCall) DoAndReturn

DoAndReturn rewrite *gomock.Call.DoAndReturn

func (*MockFilesystemServiceGetByNameCall) Return

Return rewrite *gomock.Call.Return

type MockFilesystemServiceGetCall

type MockFilesystemServiceGetCall struct {
	*gomock.Call
}

MockFilesystemServiceGetCall wrap *gomock.Call

func (*MockFilesystemServiceGetCall) Do

Do rewrite *gomock.Call.Do

func (*MockFilesystemServiceGetCall) DoAndReturn

DoAndReturn rewrite *gomock.Call.DoAndReturn

func (*MockFilesystemServiceGetCall) Return

Return rewrite *gomock.Call.Return

type MockFilesystemServiceGetOperationCall

type MockFilesystemServiceGetOperationCall struct {
	*gomock.Call
}

MockFilesystemServiceGetOperationCall wrap *gomock.Call

func (*MockFilesystemServiceGetOperationCall) Do

Do rewrite *gomock.Call.Do

func (*MockFilesystemServiceGetOperationCall) DoAndReturn

DoAndReturn rewrite *gomock.Call.DoAndReturn

func (*MockFilesystemServiceGetOperationCall) Return

Return rewrite *gomock.Call.Return

type MockFilesystemServiceListCall

type MockFilesystemServiceListCall struct {
	*gomock.Call
}

MockFilesystemServiceListCall wrap *gomock.Call

func (*MockFilesystemServiceListCall) Do

Do rewrite *gomock.Call.Do

func (*MockFilesystemServiceListCall) DoAndReturn

DoAndReturn rewrite *gomock.Call.DoAndReturn

func (*MockFilesystemServiceListCall) Return

Return rewrite *gomock.Call.Return

type MockFilesystemServiceListOperationsByParentCall

type MockFilesystemServiceListOperationsByParentCall struct {
	*gomock.Call
}

MockFilesystemServiceListOperationsByParentCall wrap *gomock.Call

func (*MockFilesystemServiceListOperationsByParentCall) DoAndReturn

DoAndReturn rewrite *gomock.Call.DoAndReturn

func (*MockFilesystemServiceListOperationsByParentCall) Return

Return rewrite *gomock.Call.Return

type MockFilesystemServiceListOperationsCall

type MockFilesystemServiceListOperationsCall struct {
	*gomock.Call
}

MockFilesystemServiceListOperationsCall wrap *gomock.Call

func (*MockFilesystemServiceListOperationsCall) Do

Do rewrite *gomock.Call.Do

func (*MockFilesystemServiceListOperationsCall) DoAndReturn

DoAndReturn rewrite *gomock.Call.DoAndReturn

func (*MockFilesystemServiceListOperationsCall) Return

Return rewrite *gomock.Call.Return

type MockFilesystemServiceMockRecorder

type MockFilesystemServiceMockRecorder struct {
	// contains filtered or unexported fields
}

MockFilesystemServiceMockRecorder is the mock recorder for MockFilesystemService.

func (*MockFilesystemServiceMockRecorder) Create

Create indicates an expected call of Create.

func (*MockFilesystemServiceMockRecorder) Delete

Delete indicates an expected call of Delete.

func (*MockFilesystemServiceMockRecorder) Filter

Filter indicates an expected call of Filter.

func (*MockFilesystemServiceMockRecorder) Get

Get indicates an expected call of Get.

func (*MockFilesystemServiceMockRecorder) GetByName

GetByName indicates an expected call of GetByName.

func (*MockFilesystemServiceMockRecorder) GetOperation

func (mr *MockFilesystemServiceMockRecorder) GetOperation(arg0, arg1 any, arg2 ...any) *MockFilesystemServiceGetOperationCall

GetOperation indicates an expected call of GetOperation.

func (*MockFilesystemServiceMockRecorder) List

List indicates an expected call of List.

func (*MockFilesystemServiceMockRecorder) ListOperations

func (mr *MockFilesystemServiceMockRecorder) ListOperations(arg0, arg1 any, arg2 ...any) *MockFilesystemServiceListOperationsCall

ListOperations indicates an expected call of ListOperations.

func (*MockFilesystemServiceMockRecorder) ListOperationsByParent

func (mr *MockFilesystemServiceMockRecorder) ListOperationsByParent(arg0, arg1 any, arg2 ...any) *MockFilesystemServiceListOperationsByParentCall

ListOperationsByParent indicates an expected call of ListOperationsByParent.

func (*MockFilesystemServiceMockRecorder) Update

Update indicates an expected call of Update.

type MockFilesystemServiceUpdateCall

type MockFilesystemServiceUpdateCall struct {
	*gomock.Call
}

MockFilesystemServiceUpdateCall wrap *gomock.Call

func (*MockFilesystemServiceUpdateCall) Do

Do rewrite *gomock.Call.Do

func (*MockFilesystemServiceUpdateCall) DoAndReturn

DoAndReturn rewrite *gomock.Call.DoAndReturn

func (*MockFilesystemServiceUpdateCall) Return

Return rewrite *gomock.Call.Return

type MockGpuClusterService

type MockGpuClusterService struct {
	// contains filtered or unexported fields
}

MockGpuClusterService is a mock of GpuClusterService interface.

func NewMockGpuClusterService

func NewMockGpuClusterService(ctrl *gomock.Controller) *MockGpuClusterService

NewMockGpuClusterService creates a new mock instance.

func (*MockGpuClusterService) Create

Create mocks base method.

func (*MockGpuClusterService) Delete

Delete mocks base method.

func (*MockGpuClusterService) EXPECT

EXPECT returns an object that allows the caller to indicate expected use.

func (*MockGpuClusterService) Filter

Filter mocks base method.

func (*MockGpuClusterService) Get

Get mocks base method.

func (*MockGpuClusterService) GetByName

GetByName mocks base method.

func (*MockGpuClusterService) GetOperation

GetOperation mocks base method.

func (*MockGpuClusterService) List

List mocks base method.

func (*MockGpuClusterService) ListOperations

ListOperations mocks base method.

func (*MockGpuClusterService) ListOperationsByParent

ListOperationsByParent mocks base method.

func (*MockGpuClusterService) Update

Update mocks base method.

type MockGpuClusterServiceCreateCall

type MockGpuClusterServiceCreateCall struct {
	*gomock.Call
}

MockGpuClusterServiceCreateCall wrap *gomock.Call

func (*MockGpuClusterServiceCreateCall) Do

Do rewrite *gomock.Call.Do

func (*MockGpuClusterServiceCreateCall) DoAndReturn

DoAndReturn rewrite *gomock.Call.DoAndReturn

func (*MockGpuClusterServiceCreateCall) Return

Return rewrite *gomock.Call.Return

type MockGpuClusterServiceDeleteCall

type MockGpuClusterServiceDeleteCall struct {
	*gomock.Call
}

MockGpuClusterServiceDeleteCall wrap *gomock.Call

func (*MockGpuClusterServiceDeleteCall) Do

Do rewrite *gomock.Call.Do

func (*MockGpuClusterServiceDeleteCall) DoAndReturn

DoAndReturn rewrite *gomock.Call.DoAndReturn

func (*MockGpuClusterServiceDeleteCall) Return

Return rewrite *gomock.Call.Return

type MockGpuClusterServiceFilterCall

type MockGpuClusterServiceFilterCall struct {
	*gomock.Call
}

MockGpuClusterServiceFilterCall wrap *gomock.Call

func (*MockGpuClusterServiceFilterCall) Do

Do rewrite *gomock.Call.Do

func (*MockGpuClusterServiceFilterCall) DoAndReturn

DoAndReturn rewrite *gomock.Call.DoAndReturn

func (*MockGpuClusterServiceFilterCall) Return

Return rewrite *gomock.Call.Return

type MockGpuClusterServiceGetByNameCall

type MockGpuClusterServiceGetByNameCall struct {
	*gomock.Call
}

MockGpuClusterServiceGetByNameCall wrap *gomock.Call

func (*MockGpuClusterServiceGetByNameCall) Do

Do rewrite *gomock.Call.Do

func (*MockGpuClusterServiceGetByNameCall) DoAndReturn

DoAndReturn rewrite *gomock.Call.DoAndReturn

func (*MockGpuClusterServiceGetByNameCall) Return

Return rewrite *gomock.Call.Return

type MockGpuClusterServiceGetCall

type MockGpuClusterServiceGetCall struct {
	*gomock.Call
}

MockGpuClusterServiceGetCall wrap *gomock.Call

func (*MockGpuClusterServiceGetCall) Do

Do rewrite *gomock.Call.Do

func (*MockGpuClusterServiceGetCall) DoAndReturn

DoAndReturn rewrite *gomock.Call.DoAndReturn

func (*MockGpuClusterServiceGetCall) Return

Return rewrite *gomock.Call.Return

type MockGpuClusterServiceGetOperationCall

type MockGpuClusterServiceGetOperationCall struct {
	*gomock.Call
}

MockGpuClusterServiceGetOperationCall wrap *gomock.Call

func (*MockGpuClusterServiceGetOperationCall) Do

Do rewrite *gomock.Call.Do

func (*MockGpuClusterServiceGetOperationCall) DoAndReturn

DoAndReturn rewrite *gomock.Call.DoAndReturn

func (*MockGpuClusterServiceGetOperationCall) Return

Return rewrite *gomock.Call.Return

type MockGpuClusterServiceListCall

type MockGpuClusterServiceListCall struct {
	*gomock.Call
}

MockGpuClusterServiceListCall wrap *gomock.Call

func (*MockGpuClusterServiceListCall) Do

Do rewrite *gomock.Call.Do

func (*MockGpuClusterServiceListCall) DoAndReturn

DoAndReturn rewrite *gomock.Call.DoAndReturn

func (*MockGpuClusterServiceListCall) Return

Return rewrite *gomock.Call.Return

type MockGpuClusterServiceListOperationsByParentCall

type MockGpuClusterServiceListOperationsByParentCall struct {
	*gomock.Call
}

MockGpuClusterServiceListOperationsByParentCall wrap *gomock.Call

func (*MockGpuClusterServiceListOperationsByParentCall) DoAndReturn

DoAndReturn rewrite *gomock.Call.DoAndReturn

func (*MockGpuClusterServiceListOperationsByParentCall) Return

Return rewrite *gomock.Call.Return

type MockGpuClusterServiceListOperationsCall

type MockGpuClusterServiceListOperationsCall struct {
	*gomock.Call
}

MockGpuClusterServiceListOperationsCall wrap *gomock.Call

func (*MockGpuClusterServiceListOperationsCall) Do

Do rewrite *gomock.Call.Do

func (*MockGpuClusterServiceListOperationsCall) DoAndReturn

DoAndReturn rewrite *gomock.Call.DoAndReturn

func (*MockGpuClusterServiceListOperationsCall) Return

Return rewrite *gomock.Call.Return

type MockGpuClusterServiceMockRecorder

type MockGpuClusterServiceMockRecorder struct {
	// contains filtered or unexported fields
}

MockGpuClusterServiceMockRecorder is the mock recorder for MockGpuClusterService.

func (*MockGpuClusterServiceMockRecorder) Create

Create indicates an expected call of Create.

func (*MockGpuClusterServiceMockRecorder) Delete

Delete indicates an expected call of Delete.

func (*MockGpuClusterServiceMockRecorder) Filter

Filter indicates an expected call of Filter.

func (*MockGpuClusterServiceMockRecorder) Get

Get indicates an expected call of Get.

func (*MockGpuClusterServiceMockRecorder) GetByName

GetByName indicates an expected call of GetByName.

func (*MockGpuClusterServiceMockRecorder) GetOperation

func (mr *MockGpuClusterServiceMockRecorder) GetOperation(arg0, arg1 any, arg2 ...any) *MockGpuClusterServiceGetOperationCall

GetOperation indicates an expected call of GetOperation.

func (*MockGpuClusterServiceMockRecorder) List

List indicates an expected call of List.

func (*MockGpuClusterServiceMockRecorder) ListOperations

func (mr *MockGpuClusterServiceMockRecorder) ListOperations(arg0, arg1 any, arg2 ...any) *MockGpuClusterServiceListOperationsCall

ListOperations indicates an expected call of ListOperations.

func (*MockGpuClusterServiceMockRecorder) ListOperationsByParent

func (mr *MockGpuClusterServiceMockRecorder) ListOperationsByParent(arg0, arg1 any, arg2 ...any) *MockGpuClusterServiceListOperationsByParentCall

ListOperationsByParent indicates an expected call of ListOperationsByParent.

func (*MockGpuClusterServiceMockRecorder) Update

Update indicates an expected call of Update.

type MockGpuClusterServiceUpdateCall

type MockGpuClusterServiceUpdateCall struct {
	*gomock.Call
}

MockGpuClusterServiceUpdateCall wrap *gomock.Call

func (*MockGpuClusterServiceUpdateCall) Do

Do rewrite *gomock.Call.Do

func (*MockGpuClusterServiceUpdateCall) DoAndReturn

DoAndReturn rewrite *gomock.Call.DoAndReturn

func (*MockGpuClusterServiceUpdateCall) Return

Return rewrite *gomock.Call.Return

type MockImageService

type MockImageService struct {
	// contains filtered or unexported fields
}

MockImageService is a mock of ImageService interface.

func NewMockImageService

func NewMockImageService(ctrl *gomock.Controller) *MockImageService

NewMockImageService creates a new mock instance.

func (*MockImageService) EXPECT

EXPECT returns an object that allows the caller to indicate expected use.

func (*MockImageService) Filter

Filter mocks base method.

func (*MockImageService) Get

Get mocks base method.

func (*MockImageService) GetByName

func (m *MockImageService) GetByName(arg0 context.Context, arg1 *v1.GetByNameRequest, arg2 ...grpc.CallOption) (*v1alpha10.Image, error)

GetByName mocks base method.

func (*MockImageService) GetLatestByFamily

GetLatestByFamily mocks base method.

func (*MockImageService) List

List mocks base method.

func (*MockImageService) ListOperationsByParent

ListOperationsByParent mocks base method.

type MockImageServiceFilterCall

type MockImageServiceFilterCall struct {
	*gomock.Call
}

MockImageServiceFilterCall wrap *gomock.Call

func (*MockImageServiceFilterCall) Do

Do rewrite *gomock.Call.Do

func (*MockImageServiceFilterCall) DoAndReturn

DoAndReturn rewrite *gomock.Call.DoAndReturn

func (*MockImageServiceFilterCall) Return

Return rewrite *gomock.Call.Return

type MockImageServiceGetByNameCall

type MockImageServiceGetByNameCall struct {
	*gomock.Call
}

MockImageServiceGetByNameCall wrap *gomock.Call

func (*MockImageServiceGetByNameCall) Do

Do rewrite *gomock.Call.Do

func (*MockImageServiceGetByNameCall) DoAndReturn

DoAndReturn rewrite *gomock.Call.DoAndReturn

func (*MockImageServiceGetByNameCall) Return

Return rewrite *gomock.Call.Return

type MockImageServiceGetCall

type MockImageServiceGetCall struct {
	*gomock.Call
}

MockImageServiceGetCall wrap *gomock.Call

func (*MockImageServiceGetCall) Do

Do rewrite *gomock.Call.Do

func (*MockImageServiceGetCall) DoAndReturn

DoAndReturn rewrite *gomock.Call.DoAndReturn

func (*MockImageServiceGetCall) Return

Return rewrite *gomock.Call.Return

type MockImageServiceGetLatestByFamilyCall

type MockImageServiceGetLatestByFamilyCall struct {
	*gomock.Call
}

MockImageServiceGetLatestByFamilyCall wrap *gomock.Call

func (*MockImageServiceGetLatestByFamilyCall) Do

Do rewrite *gomock.Call.Do

func (*MockImageServiceGetLatestByFamilyCall) DoAndReturn

DoAndReturn rewrite *gomock.Call.DoAndReturn

func (*MockImageServiceGetLatestByFamilyCall) Return

Return rewrite *gomock.Call.Return

type MockImageServiceListCall

type MockImageServiceListCall struct {
	*gomock.Call
}

MockImageServiceListCall wrap *gomock.Call

func (*MockImageServiceListCall) Do

Do rewrite *gomock.Call.Do

func (*MockImageServiceListCall) DoAndReturn

DoAndReturn rewrite *gomock.Call.DoAndReturn

func (*MockImageServiceListCall) Return

Return rewrite *gomock.Call.Return

type MockImageServiceListOperationsByParentCall

type MockImageServiceListOperationsByParentCall struct {
	*gomock.Call
}

MockImageServiceListOperationsByParentCall wrap *gomock.Call

func (*MockImageServiceListOperationsByParentCall) DoAndReturn

DoAndReturn rewrite *gomock.Call.DoAndReturn

func (*MockImageServiceListOperationsByParentCall) Return

Return rewrite *gomock.Call.Return

type MockImageServiceMockRecorder

type MockImageServiceMockRecorder struct {
	// contains filtered or unexported fields
}

MockImageServiceMockRecorder is the mock recorder for MockImageService.

func (*MockImageServiceMockRecorder) Filter

func (mr *MockImageServiceMockRecorder) Filter(arg0, arg1 any, arg2 ...any) *MockImageServiceFilterCall

Filter indicates an expected call of Filter.

func (*MockImageServiceMockRecorder) Get

func (mr *MockImageServiceMockRecorder) Get(arg0, arg1 any, arg2 ...any) *MockImageServiceGetCall

Get indicates an expected call of Get.

func (*MockImageServiceMockRecorder) GetByName

func (mr *MockImageServiceMockRecorder) GetByName(arg0, arg1 any, arg2 ...any) *MockImageServiceGetByNameCall

GetByName indicates an expected call of GetByName.

func (*MockImageServiceMockRecorder) GetLatestByFamily

func (mr *MockImageServiceMockRecorder) GetLatestByFamily(arg0, arg1 any, arg2 ...any) *MockImageServiceGetLatestByFamilyCall

GetLatestByFamily indicates an expected call of GetLatestByFamily.

func (*MockImageServiceMockRecorder) List

func (mr *MockImageServiceMockRecorder) List(arg0, arg1 any, arg2 ...any) *MockImageServiceListCall

List indicates an expected call of List.

func (*MockImageServiceMockRecorder) ListOperationsByParent

func (mr *MockImageServiceMockRecorder) ListOperationsByParent(arg0, arg1 any, arg2 ...any) *MockImageServiceListOperationsByParentCall

ListOperationsByParent indicates an expected call of ListOperationsByParent.

type MockInstanceService

type MockInstanceService struct {
	// contains filtered or unexported fields
}

MockInstanceService is a mock of InstanceService interface.

func NewMockInstanceService

func NewMockInstanceService(ctrl *gomock.Controller) *MockInstanceService

NewMockInstanceService creates a new mock instance.

func (*MockInstanceService) Create

Create mocks base method.

func (*MockInstanceService) Delete

Delete mocks base method.

func (*MockInstanceService) EXPECT

EXPECT returns an object that allows the caller to indicate expected use.

func (*MockInstanceService) Filter

Filter mocks base method.

func (*MockInstanceService) Get

Get mocks base method.

func (*MockInstanceService) GetByName

GetByName mocks base method.

func (*MockInstanceService) GetOperation

GetOperation mocks base method.

func (*MockInstanceService) List

List mocks base method.

func (*MockInstanceService) ListOperations

ListOperations mocks base method.

func (*MockInstanceService) ListOperationsByParent

ListOperationsByParent mocks base method.

func (*MockInstanceService) Start

Start mocks base method.

func (*MockInstanceService) Stop

Stop mocks base method.

func (*MockInstanceService) Update

Update mocks base method.

type MockInstanceServiceCreateCall

type MockInstanceServiceCreateCall struct {
	*gomock.Call
}

MockInstanceServiceCreateCall wrap *gomock.Call

func (*MockInstanceServiceCreateCall) Do

Do rewrite *gomock.Call.Do

func (*MockInstanceServiceCreateCall) DoAndReturn

DoAndReturn rewrite *gomock.Call.DoAndReturn

func (*MockInstanceServiceCreateCall) Return

Return rewrite *gomock.Call.Return

type MockInstanceServiceDeleteCall

type MockInstanceServiceDeleteCall struct {
	*gomock.Call
}

MockInstanceServiceDeleteCall wrap *gomock.Call

func (*MockInstanceServiceDeleteCall) Do

Do rewrite *gomock.Call.Do

func (*MockInstanceServiceDeleteCall) DoAndReturn

DoAndReturn rewrite *gomock.Call.DoAndReturn

func (*MockInstanceServiceDeleteCall) Return

Return rewrite *gomock.Call.Return

type MockInstanceServiceFilterCall

type MockInstanceServiceFilterCall struct {
	*gomock.Call
}

MockInstanceServiceFilterCall wrap *gomock.Call

func (*MockInstanceServiceFilterCall) Do

Do rewrite *gomock.Call.Do

func (*MockInstanceServiceFilterCall) DoAndReturn

DoAndReturn rewrite *gomock.Call.DoAndReturn

func (*MockInstanceServiceFilterCall) Return

Return rewrite *gomock.Call.Return

type MockInstanceServiceGetByNameCall

type MockInstanceServiceGetByNameCall struct {
	*gomock.Call
}

MockInstanceServiceGetByNameCall wrap *gomock.Call

func (*MockInstanceServiceGetByNameCall) Do

Do rewrite *gomock.Call.Do

func (*MockInstanceServiceGetByNameCall) DoAndReturn

DoAndReturn rewrite *gomock.Call.DoAndReturn

func (*MockInstanceServiceGetByNameCall) Return

Return rewrite *gomock.Call.Return

type MockInstanceServiceGetCall

type MockInstanceServiceGetCall struct {
	*gomock.Call
}

MockInstanceServiceGetCall wrap *gomock.Call

func (*MockInstanceServiceGetCall) Do

Do rewrite *gomock.Call.Do

func (*MockInstanceServiceGetCall) DoAndReturn

DoAndReturn rewrite *gomock.Call.DoAndReturn

func (*MockInstanceServiceGetCall) Return

Return rewrite *gomock.Call.Return

type MockInstanceServiceGetOperationCall

type MockInstanceServiceGetOperationCall struct {
	*gomock.Call
}

MockInstanceServiceGetOperationCall wrap *gomock.Call

func (*MockInstanceServiceGetOperationCall) Do

Do rewrite *gomock.Call.Do

func (*MockInstanceServiceGetOperationCall) DoAndReturn

DoAndReturn rewrite *gomock.Call.DoAndReturn

func (*MockInstanceServiceGetOperationCall) Return

Return rewrite *gomock.Call.Return

type MockInstanceServiceListCall

type MockInstanceServiceListCall struct {
	*gomock.Call
}

MockInstanceServiceListCall wrap *gomock.Call

func (*MockInstanceServiceListCall) Do

Do rewrite *gomock.Call.Do

func (*MockInstanceServiceListCall) DoAndReturn

DoAndReturn rewrite *gomock.Call.DoAndReturn

func (*MockInstanceServiceListCall) Return

Return rewrite *gomock.Call.Return

type MockInstanceServiceListOperationsByParentCall

type MockInstanceServiceListOperationsByParentCall struct {
	*gomock.Call
}

MockInstanceServiceListOperationsByParentCall wrap *gomock.Call

func (*MockInstanceServiceListOperationsByParentCall) DoAndReturn

DoAndReturn rewrite *gomock.Call.DoAndReturn

func (*MockInstanceServiceListOperationsByParentCall) Return

Return rewrite *gomock.Call.Return

type MockInstanceServiceListOperationsCall

type MockInstanceServiceListOperationsCall struct {
	*gomock.Call
}

MockInstanceServiceListOperationsCall wrap *gomock.Call

func (*MockInstanceServiceListOperationsCall) Do

Do rewrite *gomock.Call.Do

func (*MockInstanceServiceListOperationsCall) DoAndReturn

DoAndReturn rewrite *gomock.Call.DoAndReturn

func (*MockInstanceServiceListOperationsCall) Return

Return rewrite *gomock.Call.Return

type MockInstanceServiceMockRecorder

type MockInstanceServiceMockRecorder struct {
	// contains filtered or unexported fields
}

MockInstanceServiceMockRecorder is the mock recorder for MockInstanceService.

func (*MockInstanceServiceMockRecorder) Create

func (mr *MockInstanceServiceMockRecorder) Create(arg0, arg1 any, arg2 ...any) *MockInstanceServiceCreateCall

Create indicates an expected call of Create.

func (*MockInstanceServiceMockRecorder) Delete

func (mr *MockInstanceServiceMockRecorder) Delete(arg0, arg1 any, arg2 ...any) *MockInstanceServiceDeleteCall

Delete indicates an expected call of Delete.

func (*MockInstanceServiceMockRecorder) Filter

func (mr *MockInstanceServiceMockRecorder) Filter(arg0, arg1 any, arg2 ...any) *MockInstanceServiceFilterCall

Filter indicates an expected call of Filter.

func (*MockInstanceServiceMockRecorder) Get

func (mr *MockInstanceServiceMockRecorder) Get(arg0, arg1 any, arg2 ...any) *MockInstanceServiceGetCall

Get indicates an expected call of Get.

func (*MockInstanceServiceMockRecorder) GetByName

func (mr *MockInstanceServiceMockRecorder) GetByName(arg0, arg1 any, arg2 ...any) *MockInstanceServiceGetByNameCall

GetByName indicates an expected call of GetByName.

func (*MockInstanceServiceMockRecorder) GetOperation

func (mr *MockInstanceServiceMockRecorder) GetOperation(arg0, arg1 any, arg2 ...any) *MockInstanceServiceGetOperationCall

GetOperation indicates an expected call of GetOperation.

func (*MockInstanceServiceMockRecorder) List

func (mr *MockInstanceServiceMockRecorder) List(arg0, arg1 any, arg2 ...any) *MockInstanceServiceListCall

List indicates an expected call of List.

func (*MockInstanceServiceMockRecorder) ListOperations

func (mr *MockInstanceServiceMockRecorder) ListOperations(arg0, arg1 any, arg2 ...any) *MockInstanceServiceListOperationsCall

ListOperations indicates an expected call of ListOperations.

func (*MockInstanceServiceMockRecorder) ListOperationsByParent

func (mr *MockInstanceServiceMockRecorder) ListOperationsByParent(arg0, arg1 any, arg2 ...any) *MockInstanceServiceListOperationsByParentCall

ListOperationsByParent indicates an expected call of ListOperationsByParent.

func (*MockInstanceServiceMockRecorder) Start

func (mr *MockInstanceServiceMockRecorder) Start(arg0, arg1 any, arg2 ...any) *MockInstanceServiceStartCall

Start indicates an expected call of Start.

func (*MockInstanceServiceMockRecorder) Stop

func (mr *MockInstanceServiceMockRecorder) Stop(arg0, arg1 any, arg2 ...any) *MockInstanceServiceStopCall

Stop indicates an expected call of Stop.

func (*MockInstanceServiceMockRecorder) Update

func (mr *MockInstanceServiceMockRecorder) Update(arg0, arg1 any, arg2 ...any) *MockInstanceServiceUpdateCall

Update indicates an expected call of Update.

type MockInstanceServiceStartCall

type MockInstanceServiceStartCall struct {
	*gomock.Call
}

MockInstanceServiceStartCall wrap *gomock.Call

func (*MockInstanceServiceStartCall) Do

Do rewrite *gomock.Call.Do

func (*MockInstanceServiceStartCall) DoAndReturn

DoAndReturn rewrite *gomock.Call.DoAndReturn

func (*MockInstanceServiceStartCall) Return

Return rewrite *gomock.Call.Return

type MockInstanceServiceStopCall

type MockInstanceServiceStopCall struct {
	*gomock.Call
}

MockInstanceServiceStopCall wrap *gomock.Call

func (*MockInstanceServiceStopCall) Do

Do rewrite *gomock.Call.Do

func (*MockInstanceServiceStopCall) DoAndReturn

DoAndReturn rewrite *gomock.Call.DoAndReturn

func (*MockInstanceServiceStopCall) Return

Return rewrite *gomock.Call.Return

type MockInstanceServiceUpdateCall

type MockInstanceServiceUpdateCall struct {
	*gomock.Call
}

MockInstanceServiceUpdateCall wrap *gomock.Call

func (*MockInstanceServiceUpdateCall) Do

Do rewrite *gomock.Call.Do

func (*MockInstanceServiceUpdateCall) DoAndReturn

DoAndReturn rewrite *gomock.Call.DoAndReturn

func (*MockInstanceServiceUpdateCall) Return

Return rewrite *gomock.Call.Return

Jump to